"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const file_temp_1 = require("../../libs/file-temp");
const testing_1 = require("../../testing");
const yaml_1 = require("yaml");
const root_scene_1 = require("../root-scene");
const scene_1 = require("./scene");
let scene;
let encryptedFile;
const password = 'example';
beforeEach(async () => {
    await testing_1.Testing.reset();
});
afterEach(async () => {
    await scene.dispose();
});
afterAll(() => {
    encryptedFile && (0, fs_1.unlinkSync)(encryptedFile);
});
test('Check localVars and globalVars', async () => {
    const tmp = new file_temp_1.FileTemp();
    const tmp1 = new file_temp_1.FileTemp();
    await tmp.create(`
- vars:
    localVars: my local vars in scene
    GlobalVars1: My Global Vars 1 in scene
- scene:
    path: ${tmp1.file}
- echo: \${vars.localVars}
- echo: \${vars.GlobalVars1}
- echo: \${vars.rootLocalVars}
- echo: \${vars.GlobalVars2}
`);
    await tmp1.create(`
- vars:
    localVars1: my local vars 1 in scene 1
    GlobalVars1: My Global Vars 1 in scene 1

- echo: \${vars.localVars}
- echo: \${vars.localVars1}
- echo: \${vars.GlobalVars1}
- echo: \${vars.rootLocalVars}
- echo: \${vars.GlobalVars2}
`);
    try {
        scene = await testing_1.Testing.newElement(scene_1.Scene, {
            content: `
- vars:
    rootLocalVars: my local vars in root
    GlobalVars1: My Global 1 Vars in root
    GlobalVars2: My Global 2 Vars in root

- scene:
    path: ${tmp.file}

- echo: \${vars.rootLocalVars}
- echo: \${vars.localVars}
- echo: \${vars.GlobalVars1}
- echo: \${vars.GlobalVars2}
`
        });
        const [, scene1, echo1, echo2, echo3, echo4] = await scene.exec() || [];
        const [, scene2, echo11, echo12, echo13, echo14] = scene1.result || [];
        const [, echo21, echo22, echo23, echo24, echo25] = scene2.result || [];
        expect(echo21.result).toBeUndefined();
        expect(echo22.result).toBe('my local vars 1 in scene 1');
        expect(echo23.result).toBe('My Global Vars 1 in scene 1');
        expect(echo24.result).toBeUndefined();
        expect(echo25.result).toBe('My Global 2 Vars in root');
        expect(echo11.result).toBe('my local vars in scene');
        expect(echo12.result).toBe('My Global Vars 1 in scene');
        expect(echo13.result).toBeUndefined();
        expect(echo14.result).toBe('My Global 2 Vars in root');
        expect(echo1.result).toBe('my local vars in root');
        expect(echo2.result).toBeUndefined();
        expect(echo3.result).toBe('My Global 1 Vars in root');
        expect(echo4.result).toBe('My Global 2 Vars in root');
    }
    finally {
        tmp.remove();
    }
});
test('Should load vars from yaml file', async () => {
    const tmpFile = new file_temp_1.FileTemp('.yaml');
    try {
        await tmpFile.create((0, yaml_1.stringify)({
            name: 'name 1',
            age: 1,
            male: true,
            more: {
                address: '1',
                num: 2,
                married: false
            }
        }));
        scene = new root_scene_1.RootScene({
            content: `
vars_file: ${tmpFile.file}
runs:
  - Test env
`
        }, testing_1.Testing.logger);
        await scene.exec();
        expect(scene.localVars.name).toBe('name 1');
        expect(scene.localVars.age).toBe(1);
        expect(scene.localVars.male).toBe(true);
        expect(scene.localVars.more).toEqual({
            address: '1',
            num: 2,
            married: false
        });
    }
    finally {
        tmpFile.remove();
    }
});
test('Should load vars from json file', async () => {
    await scene.dispose();
    const tmpFile = new file_temp_1.FileTemp('.json');
    try {
        await tmpFile.create(JSON.stringify({
            name: 'name 1',
            age: 1,
            male: true,
            more: {
                address: '1',
                num: 2,
                married: false
            }
        }));
        scene = new root_scene_1.RootScene({
            content: `
vars_file: ${tmpFile.file}
runs:
  - Test env
`
        }, testing_1.Testing.logger);
        await scene.exec();
        expect(scene.localVars.name).toBe('name 1');
        expect(scene.localVars.age).toBe(1);
        expect(scene.localVars.male).toBe(true);
        expect(scene.localVars.more).toEqual({
            address: '1',
            num: 2,
            married: false
        });
    }
    finally {
        tmpFile.remove();
    }
});
test('Should override env when load scene', async () => {
    await scene.dispose();
    process.env.NAME = 'name 1';
    process.env.age = '1';
    process.env.male = '1';
    process.env.more_address = '1';
    process.env.MORE_NUM = '2';
    process.env.MORE_MARRied = 'no';
    scene = new root_scene_1.RootScene({
        content: `
vars:
  name: name 0
  age: 0
  male: false
  more:
    address: addr 1
    num: 1
    married: true
runs:
  - Test env
`
    }, testing_1.Testing.logger);
    await scene.exec();
    expect(scene.localVars.name).toBe('name 1');
    expect(scene.localVars.age).toBe(1);
    expect(scene.localVars.male).toBe(true);
    expect(scene.localVars.more).toEqual({
        address: '1',
        num: 2,
        married: false
    });
});
test('Should load successfully from text content with only list items', async () => {
    scene = await testing_1.Testing.newElement(scene_1.Scene, { content: '- echo: Hello' });
    await scene.exec();
    expect(scene.result).toHaveLength(1);
});
test('Should load successfully from text content with full props', async () => {
    scene = await testing_1.Testing.newElement(scene_1.Scene, {
        content: `
title: test
runs: 
  - echo: Hello
`
    });
    await scene.exec();
    expect(scene.result).toHaveLength(1);
});
test('Should load successfully from file', async () => {
    const tmp = new file_temp_1.FileTemp();
    try {
        await tmp.create(`
title: Test here
runs:
  - Hello
  - World
`);
        scene = await testing_1.Testing.newElement(scene_1.Scene, { path: tmp.file });
        await scene.exec();
        expect(scene.result).toHaveLength(2);
    }
    finally {
        tmp.remove();
    }
});
test('Should generate a generated scene file when set password', async () => {
    const tmp = new file_temp_1.FileTemp('.yaml');
    try {
        await tmp.create(`
title: Test here
password: ${password}
runs:
  - Hello
  - World
`);
        scene = await testing_1.Testing.newElement(scene_1.Scene, { path: tmp.file });
        await scene.exec();
        expect(scene.encryptedPath && (0, fs_1.existsSync)(scene.encryptedPath)).toBe(true);
        encryptedFile = scene.encryptedPath || '';
    }
    finally {
        tmp.remove();
    }
});
test('Load a encrypted scene file', async () => {
    scene = await testing_1.Testing.newElement(scene_1.Scene, { path: encryptedFile, password });
    await scene.exec();
    expect(scene.result).toHaveLength(2);
});
test('Should run echo element', async () => {
    scene = await testing_1.Testing.newElement(scene_1.Scene, {
        content: `
- echo:
    content: 'ok'
`
    });
    const [echo] = await scene.exec();
    expect(echo.result).toBe('ok');
    await scene.dispose();
});
//# sourceMappingURL=scene.spec.js.map